# geoshort


[![image](https://img.shields.io/pypi/v/geoshort.svg)](https://pypi.python.org/pypi/geoshort)
[![image](https://img.shields.io/conda/vn/conda-forge/geoshort.svg)](https://anaconda.org/conda-forge/geoshort)


**A python package for class project**


-   Free software: MIT License
-   Documentation: https://BrycenHarris.github.io/geoshort
    

## Features

-   TODO
